/**
 * A representation of a complex number.
 * 
 * @author Sven van Nigtevecht
 * @version 1.0
 */
public class ComplexNumber
{
    /** The real component of the complex number. */
    public double normal;
    /** The real imaginary of the complex number. */
    public double i;
    
    /**
     * Create a new ComplexNumber, with
     * both the real component and the imaginary
     * component being 0.0
     */
    public ComplexNumber()
    {
        this(.0, .0);
    }
    
    /**
     * Create a new ComplexNumber.
     * @param normal The real compontent of the
     * complex number.
     * @param imaginary The imaginary compontent of the
     * complex number.
     */
    public ComplexNumber(double normal, double imaginary)
    {
        this.normal = normal;
        this.i = imaginary;
    }
    
    /**
     * Create a new ComplexNumber.
     * @param number A string containing the
     * complex number. It may include empty
     * spaces, but is has to include the +
     * sign and the imaginary component must
     * be represented with an i character
     * at the end.
     */
    public ComplexNumber(String number)
    {
        if (number.contains(" ")) {
            String newString = "";
            char[] chars = number.toCharArray();
            for (char a : chars) {
                if (a != ' ') {
                    newString += a;
                }
            }
            number = newString;
        }
        char[] chars = number.toCharArray();
        String first = null;
        String second = null;
        int index = 0;
        int temp = 0;
        for (char a : chars) {
            if (a == '+') {
                first = number.substring(0, index -1);
                temp = index +1;
            } else if (a == 'i') {
                second = number.substring(temp, index -1);
            }
            index++;
        }
        this.normal = Double.parseDouble(first);
        this.i = Double.parseDouble(second);
    }
    
    /** METHODS: */
    
    /**
     * Returns a new complex number, which is the
     * result of another complex number added to
     * this one.
     */
    public void add(ComplexNumber number)
    {
        this.normal += number.normal;
        this.i += number.i;
    }
    
    /**
     * Returns a new complex number, which is the
     * result of another complex number multiplied
     * with this one.
     */
    public void multiply(ComplexNumber number)
    {
        double real = normal *number.normal;
        double real2 = i *number.i;
        double imaginary = (normal *number.i) +(i *number.normal);
        
        this.normal = real -real2;
        this.i = imaginary;
    }
    
    /**
     * Returns the distance of the complex number
     * to the origin, squared.
     */
    public double absSquared()
    {
        return normal *normal + i *i;
    }
    
    /**
     * Returns the distance of the complex number
     * to the origin.
     */
    public double abs()
    {
        return Math.sqrt(normal *normal + i *i);
    }
}