import greenfoot.core.WorldHandler;
import java.awt.event.MouseWheelListener;
import java.awt.event.MouseWheelEvent;
import javax.swing.JPanel;

/**
 * @author Sven van Nigtevecht
 * @version 1.0
 */
public class ScrollListener implements MouseWheelListener
{
    private Runnable runnable;
    private int amount;
    
    /**
     * Create a new ScrollListener
     */
    public ScrollListener() {}
    
    /**
     * Starts the scroll listener listening
     * to the scroll wheel.
     */
    public void start()
    {
        JPanel panel = WorldHandler.getInstance().getWorldCanvas();
        panel.addMouseWheelListener(this);
    }
    
    /**
     * Stops the scroll listener listening
     * to the scroll wheel.
     */
    public void stop()
    {
        JPanel panel = WorldHandler.getInstance().getWorldCanvas();
        panel.removeMouseWheelListener(this);
    }
    
    /**
     * Sets the runnable which will get
     * executed when the mouse wheel
     * scrolled.
     */
    public void setRunnable(Runnable runnable)
    {
        this.runnable = runnable;
    }
    
    /**
     * Returns the amount of rotation the
     * mouse wheel has last done. When it
     * scrolls again, this data will be removed
     * and changed by its new rotation.
     */
    public int getRotationAmount()
    {
        return amount;
    }
    
    /**
     * Respond to the mouse wheel.
     */
    public void mouseWheelMoved(MouseWheelEvent e)
    {
        amount = e.getWheelRotation();
        if (runnable != null)
            runnable.run();
        e.consume();
    }
}